<no title> — Transmogrify 1.0.1b2 documentation

Transmogrify 1.0.1b2 documentation

#

- Table of Contents
- index

- Main Page

- Getting Started
- Installation
- Django Template Tag
- Web Server Integration
- Reference

Enter search terms or a module, class or function name.

1. Find gravity of the image
2. Fit the smallest dimension into the available hole
3. Center the gravity

© Copyright 2010, The Washington Times. Created using Sphinx 1.3b2.

<no title>